==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
var WebRangeSliderValueDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderValueDescriptionMetadata, _super);
    function WebRangeSliderValueDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderValueDescriptionMetadata.b = function (a) {
        if (WebRangeSliderValueDescriptionMetadata.a == null) {
            WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
        }
        if (a.g(WebRangeSliderValueDescriptionMetadata.a)) {
            return;
        }
        a.s(WebRangeSliderValueDescriptionMetadata.a);
    };
    WebRangeSliderValueDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RangeSliderValue");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
    };
    WebRangeSliderValueDescriptionMetadata.d = function (a) {
        WebRangeSliderValueDescriptionMetadata.b(a);
        a.u("WebRangeSliderValue", function () { return new WebRangeSliderValueDescription(); });
        a.t("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
    };
    WebRangeSliderValueDescriptionMetadata.$t = markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
}(Base));
export { WebRangeSliderValueDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebRangeSliderValueDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueDescription } from "./WebRangeSliderValueDescription";
/**
 * @hidden
 */
var WebRangeSliderValueDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderValueDescriptionMetadata, _super);
    function WebRangeSliderValueDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderValueDescriptionMetadata.b = function (a) {
        if (WebRangeSliderValueDescriptionMetadata.a == null) {
            WebRangeSliderValueDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderValueDescriptionMetadata.c(WebRangeSliderValueDescriptionMetadata.a);
        }
        if (a.j(WebRangeSliderValueDescriptionMetadata.a)) {
            return;
        }
        a.y(WebRangeSliderValueDescriptionMetadata.a);
    };
    WebRangeSliderValueDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:RangeSliderValue");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
    };
    WebRangeSliderValueDescriptionMetadata.d = function (a) {
        WebRangeSliderValueDescriptionMetadata.b(a);
        a.aa("WebRangeSliderValue", function () { return new WebRangeSliderValueDescription(); });
        a.z("WebRangeSliderValue", WebRangeSliderValueDescriptionMetadata.a);
    };
    WebRangeSliderValueDescriptionMetadata.$t = markType(WebRangeSliderValueDescriptionMetadata, 'WebRangeSliderValueDescriptionMetadata');
    WebRangeSliderValueDescriptionMetadata.a = null;
    return WebRangeSliderValueDescriptionMetadata;
}(Base));
export { WebRangeSliderValueDescriptionMetadata };
